import { CustomMDX } from "@/app/components/mdx-components";
import { Metadata } from "next";
import { generateEmbed } from "@/app/common/embed";
import { Title } from "@/app/components/title";
import { DocsContentMetadata, getDocContent, getDocsContent } from "@/app/common/documentation";
import {
  Breadcrumb,
  BreadcrumbItem,
  BreadcrumbLink,
  BreadcrumbList,
  BreadcrumbSeparator,
} from "@/app/components/ui/breadcrumb";
import { capitalizeFirstLetter } from "@/app/common/string-utils";
import { notFound } from "next/navigation";
import { GithubLink } from "@/app/components/docs/github-link";
import { CommandMenu } from "@/app/components/command-menu";

type DocumentationPageParams = {
  params: {
    /**
     * The slug for the documentation page.
     */
    slug?: string[];
  };
};

export async function generateStaticParams() {
  let documentationPages: DocsContentMetadata[] = getDocsContent();

  return documentationPages.map(page => ({
    slug: [page.slug],
  }));
}

export async function generateMetadata({ params: { slug } }: DocumentationPageParams): Promise<Metadata> {
  const page: DocsContentMetadata | undefined = getDocContent(slug);

  // Fallback to page not found
  if (!page) {
    return generateEmbed({
      title: "Page not found",
      description: "The documentation page was not found",
    });
  }

  return generateEmbed({
    title: `${page.title} - Documentation`,
    description: `${page.summary}\n\nClick to view this page`,
  });
}

export default function Page({ params: { slug } }: DocumentationPageParams) {
  const page: DocsContentMetadata | undefined = getDocContent(slug);

  // Page was not found, show an error page
  if (!page) {
    return notFound();
  }

  const slugParts: string[] = page.slug.split("/");
  const isHome: boolean = slugParts.length == 1;

  return (
    <div className="w-full h-full px-4 flex flex-col">
      <div className="flex justify-between items-center">
        {/* The breadcrumb for the documentation page */}
        <Breadcrumb>
          <BreadcrumbList>
            <BreadcrumbItem>
              <BreadcrumbLink href={`/docs`}>Home</BreadcrumbLink>
            </BreadcrumbItem>
            {!isHome &&
              slugParts.map((slug, index, array) => {
                const path: string = array.slice(0, index + 1).join("/");
                const name: string = slug.includes("-")
                  ? slug.split("-").map(capitalizeFirstLetter).join(" ")
                  : capitalizeFirstLetter(slug);

                return (
                  <div key={slug} className="flex items-center ">
                    <BreadcrumbSeparator className="pr-1.5" />
                    <BreadcrumbItem>
                      <BreadcrumbLink href={`/docs/${path}`}>{capitalizeFirstLetter(name)}</BreadcrumbLink>
                    </BreadcrumbItem>
                  </div>
                );
              })}
          </BreadcrumbList>
        </Breadcrumb>

        {/* The Git link for the documentation page */}
        <div className="flex flex-row gap-2 items-center">
          <GithubLink page={page} />
        </div>
      </div>

      {/* The documentation page title and description */}
      <div className="text-center mb-4">
        <Title title={page.title} subtitle={page.summary} />
      </div>

      {/* The content of the documentation page */}
      <div className="text-left w-full pb-[2rem]">
        <CustomMDX source={page.content} />
      </div>
    </div>
  );
}
